package minecraft.gui;

import minecraft.player.InvalidCharacterParamsException;
import minecraft.player.Steve;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

// toto cele z hladiska OOP nie je uplne okej, je to len na vyskusanie a osahanie si Swingu :)
public class SteveGUI extends JFrame {

    private final DefaultListModel<Steve> steveListModel;
    private final JList<Steve> steveList;

    public SteveGUI() {
        steveListModel = new DefaultListModel<>();
        steveList = new JList<>(steveListModel);

        setTitle("Steve Spawner");
        setSize(400, 300);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLayout(new BorderLayout());

        JButton dmgButton = new JButton("Spawn Steve");
        dmgButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                try {
                    Thread.sleep(10000);
                } catch (InterruptedException ex) {
                    throw new RuntimeException(ex);
                }
            }
        });

        add(dmgButton, BorderLayout.NORTH);

//        JButton spawnButton = new JButton("Spawn Steve");
//        spawnButton.addActionListener(new ActionListener() {
//            @Override
//            public void actionPerformed(ActionEvent e) {
//                spawnSteve();
//            }
//        });
//
//        add(spawnButton, BorderLayout.NORTH);

        JScrollPane scrollPane = new JScrollPane(steveList);
        add(scrollPane, BorderLayout.CENTER);

        // pozor nefunguje ked uz je nieco oznacene, bolo by to treba riesit mouselistenerom napriklad, ale netreba momentalne
        steveList.addListSelectionListener(e -> {
            System.out.println(e);
            // naraz sa vypali mouseDown and mouseUp preto je tu tento if
            if (!e.getValueIsAdjusting()) {
                Steve selectedSteve = steveList.getSelectedValue();
                if (selectedSteve != null) {
                    showSteveDetails(selectedSteve);
                }
            }
        });
    }

    private void spawnSteve() {
        JTextField nameField = new JTextField();
        JTextField healthField = new JTextField();
        JTextField maxHealthField = new JTextField();
        JTextField attackPowerField = new JTextField();
        JTextField defensePowerField = new JTextField();
        JTextField hungerField = new JTextField();
        JTextField maxHungerField = new JTextField();
        JCheckBox godModeCheckBox = new JCheckBox("God Mode");

        JPanel panel = new JPanel(new GridLayout(0, 2));
        panel.add(new JLabel("Name:"));
        panel.add(nameField);
        panel.add(new JLabel("Health:"));
        panel.add(healthField);
        panel.add(new JLabel("Max Health:"));
        panel.add(maxHealthField);
        panel.add(new JLabel("Attack Power:"));
        panel.add(attackPowerField);
        panel.add(new JLabel("Defense Power:"));
        panel.add(defensePowerField);
        panel.add(new JLabel("Hunger:"));
        panel.add(hungerField);
        panel.add(new JLabel("Max Hunger:"));
        panel.add(maxHungerField);
        panel.add(new JLabel("God Mode:"));
        panel.add(godModeCheckBox);

        int result = JOptionPane.showConfirmDialog(
                this,
                panel,
                "Spawn Steve",
                JOptionPane.OK_CANCEL_OPTION,
                JOptionPane.PLAIN_MESSAGE
        );

        if (result == JOptionPane.OK_OPTION) {
            try {
                String name = nameField.getText();
                int health = Integer.parseInt(healthField.getText());
                int maxHealth = Integer.parseInt(maxHealthField.getText());
                int attackPower = Integer.parseInt(attackPowerField.getText());
                int defensePower = Integer.parseInt(defensePowerField.getText());
                int hunger = Integer.parseInt(hungerField.getText());
                int maxHunger = Integer.parseInt(maxHungerField.getText());
                boolean godMode = godModeCheckBox.isSelected();

                Steve newSteve = new Steve(name, health, maxHealth, attackPower, defensePower, hunger, maxHunger, godMode);
                steveListModel.addElement(newSteve);
            } catch (NumberFormatException ex) {
                JOptionPane.showMessageDialog(this, "Invalid input. Please enter numeric values for health, attack power, etc.", "Error", JOptionPane.ERROR_MESSAGE);
            } catch (InvalidCharacterParamsException ex) {
                JOptionPane.showMessageDialog(this, "Error creating Steve: " + ex.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
            }
        }
    }

    private void showSteveDetails(Steve steve) {
        JFrame detailsFrame = new JFrame("Steve Details");
        detailsFrame.setSize(300, 200);
        detailsFrame.setLayout(new GridLayout(0, 2));

        detailsFrame.add(new JLabel("Name:"));
        detailsFrame.add(new JLabel(steve.getName()));
        detailsFrame.add(new JLabel("Health:"));
        detailsFrame.add(new JLabel(String.valueOf(steve.getHealth())));
        detailsFrame.add(new JLabel("Max Health:"));
        detailsFrame.add(new JLabel(String.valueOf(steve.getMaxHealth())));
        detailsFrame.add(new JLabel("Attack Power:"));
        detailsFrame.add(new JLabel(String.valueOf(steve.getAttackPower())));
        detailsFrame.add(new JLabel("Defense Power:"));
        detailsFrame.add(new JLabel(String.valueOf(steve.getDefensePower())));
        detailsFrame.add(new JLabel("Hunger:"));
        detailsFrame.add(new JLabel(String.valueOf(steve.getHunger())));
        detailsFrame.add(new JLabel("Max Hunger:"));
        detailsFrame.add(new JLabel(String.valueOf(steve.getMaxHunger())));
        detailsFrame.add(new JLabel("God Mode:"));
        detailsFrame.add(new JLabel(steve.isGodMode() ? "Yes" : "No"));

        detailsFrame.setVisible(true);
    }

    public static void main(String[] args) {
        SteveGUI gui = new SteveGUI();
        gui.setVisible(true);
    }
}