package minecraft.gui.mvc;

import minecraft.player.Steve;
import java.util.List;
import java.util.Scanner;

public class ConsoleSteveView implements SteveView {
    private SteveListener listener;
    private Scanner scanner = new Scanner(System.in);

    @Override
    public void showAllSteves(List<Steve> steves) {
        System.out.println("\n--- List of Steves ---");
        for (int i = 0; i < steves.size(); i++) {
            System.out.println(i + ": " + steves.get(i));
        }
    }

    @Override
    public void showError(String message) {
        System.out.println("ERROR: " + message);
    }

    @Override
    public void showSuccess(String message) {
        System.out.println("SUCCESS: " + message);
    }

    @Override
    public void clearForm() {
        System.out.println("\nForm cleared.");
    }

    @Override
    public void setFormFields(Steve steve) {
        System.out.println("\nSelected Steve: " + steve);
    }

    @Override
    public void setSteveListener(SteveListener listener) {
        this.listener = listener;
    }

    public void showMenu() {
        while (true) {
            System.out.println("\n1. Add Steve");
            System.out.println("2. Update Steve");
            System.out.println("3. Delete Steve");
            System.out.println("4. Select Steve");
            System.out.println("5. Exit");
            System.out.print("Enter your choice: ");
            int choice = scanner.nextInt();
            scanner.nextLine();

            switch (choice) {
                case 1 -> addSteve();
                case 2 -> updateSteve();
                case 3 -> deleteSteve();
                case 4 -> selectSteve();
                case 5 -> {
                    System.out.println("Exiting...");
                    return;
                }
                default -> System.out.println("Invalid choice, try again.");
            }
        }
    }

    private void addSteve() {
        System.out.print("Enter name: ");
        String name = scanner.nextLine();
        System.out.print("Enter health: ");
        int health = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter maxHealth: ");
        int maxHealth = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter attackPower: ");
        int attackPower = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter defensePower: ");
        int defensePower = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter hunger: ");
        int hunger = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter maxHunger: ");
        int maxHunger = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter godMode: ");
        boolean godMode = Boolean.parseBoolean(scanner.nextLine());

        listener.onAddSteve(name, health, maxHealth, attackPower, defensePower, hunger, maxHunger, godMode);
    }

    private void updateSteve() {
        System.out.print("Enter index to update: ");
        int index = scanner.nextInt();
        scanner.nextLine();
        System.out.print("Enter name: ");
        String name = scanner.nextLine();
        System.out.print("Enter health: ");
        int health = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter maxHealth: ");
        int maxHealth = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter attackPower: ");
        int attackPower = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter defensePower: ");
        int defensePower = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter hunger: ");
        int hunger = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter maxHunger: ");
        int maxHunger = Integer.parseInt(scanner.nextLine());
        System.out.print("Enter godMode: ");
        boolean godMode = Boolean.parseBoolean(scanner.nextLine());
        listener.onUpdateSteve(index, name, health, maxHealth, attackPower, defensePower, hunger, maxHunger, godMode);
    }

    private void deleteSteve() {
        System.out.print("Enter index to delete: ");
        int index = scanner.nextInt();
        listener.onDeleteSteve(index);
    }

    private void selectSteve() {
        System.out.print("Enter index to select: ");
        int index = scanner.nextInt();
        listener.onSteveSelected(index);
    }
}

