package minecraft.gui.mvc;

import minecraft.player.InvalidCharacterParamsException;

public class SteveController implements SteveView.SteveListener {
    private SteveView view;
    private SteveService model;

    public SteveController(SteveView view, SteveService model) {
        this.view = view;
        this.model = model;
        this.view.setSteveListener(this);
        updateView();
    }

    private void updateView() {
        view.showAllSteves(model.getAllSteves());
    }

    @Override
    public void onAddSteve(String name, int health, int maxHealth, int attackPower,
                           int defensePower, int hunger, int maxHunger, boolean godMode) {
        try {
            model.createSteve(name, health, maxHealth, attackPower, defensePower,
                    hunger, maxHunger, godMode);
            updateView();
            view.clearForm();
            view.showSuccess("Steve created successfully!");
        } catch (InvalidCharacterParamsException e) {
            view.showError(e.getMessage());
        }
    }

    @Override
    public void onUpdateSteve(int index, String name, int health, int maxHealth,
                              int attackPower, int defensePower, int hunger,
                              int maxHunger, boolean godMode) {
        try {
            model.updateSteve(index, name, health, maxHealth, attackPower,
                    defensePower, hunger, maxHunger, godMode);
            updateView();
            view.showSuccess("Steve updated successfully!");
        } catch (InvalidCharacterParamsException e) {
            view.showError(e.getMessage());
        }
    }

    @Override
    public void onDeleteSteve(int index) {
        model.deleteSteve(index);
        updateView();
        view.clearForm();
        view.showSuccess("Steve deleted successfully!");
    }

    @Override
    public void onClearForm() {
        view.clearForm();
    }

    @Override
    public void onSteveSelected(int index) {
        view.setFormFields(model.getSteve(index));
    }
}

