package minecraft.gui.mvc;

import minecraft.player.Steve;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;

public class SwingSteveView extends JFrame implements SteveView {
    private SteveListener listener;
    private JList<Steve> steveList;
    private DefaultListModel<Steve> listModel;

    private JTextField nameField = new JTextField();
    private JTextField healthField = new JTextField();
    private JTextField maxHealthField = new JTextField();
    private JTextField attackPowerField = new JTextField();
    private JTextField defensePowerField = new JTextField();
    private JTextField hungerField = new JTextField();
    private JTextField maxHungerField = new JTextField();
    private JCheckBox godModeCheckBox = new JCheckBox("God Mode");

    public SwingSteveView() {
        super("Steve CRUD - MVC Pattern");
        setSize(800, 600);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLayout(new BorderLayout());

        initFormPanel();
        initListPanel();
        initButtonPanel();
    }

    private void initFormPanel() {
        JPanel formPanel = new JPanel(new GridLayout(0, 2, 5, 5));
        formPanel.setBorder(BorderFactory.createTitledBorder("Steve Details"));

        formPanel.add(new JLabel("Name:"));
        formPanel.add(nameField);
        formPanel.add(new JLabel("Health:"));
        formPanel.add(healthField);
        formPanel.add(new JLabel("Max Health:"));
        formPanel.add(maxHealthField);
        formPanel.add(new JLabel("Attack Power:"));
        formPanel.add(attackPowerField);
        formPanel.add(new JLabel("Defense Power:"));
        formPanel.add(defensePowerField);
        formPanel.add(new JLabel("Hunger:"));
        formPanel.add(hungerField);
        formPanel.add(new JLabel("Max Hunger:"));
        formPanel.add(maxHungerField);
        formPanel.add(new JLabel(""));
        formPanel.add(godModeCheckBox);

        add(formPanel, BorderLayout.NORTH);
    }

    private void initListPanel() {
        JPanel listPanel = new JPanel(new BorderLayout());
        listModel = new DefaultListModel<>();
        steveList = new JList<>(listModel);
        steveList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

        steveList.addListSelectionListener(e -> {
            if (!e.getValueIsAdjusting()) {
                int selectedIndex = steveList.getSelectedIndex();
                if (selectedIndex != -1 && listener != null) {
                    listener.onSteveSelected(selectedIndex);
                }
            }
        });

        listPanel.add(new JScrollPane(steveList), BorderLayout.CENTER);
        add(listPanel, BorderLayout.CENTER);
    }

    private void initButtonPanel() {
        JPanel buttonPanel = new JPanel(new FlowLayout());

        JButton addButton = new JButton("Add");
        addButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (listener != null) {
                    try {
                        listener.onAddSteve(
                                nameField.getText(),
                                Integer.parseInt(healthField.getText()),
                                Integer.parseInt(maxHealthField.getText()),
                                Integer.parseInt(attackPowerField.getText()),
                                Integer.parseInt(defensePowerField.getText()),
                                Integer.parseInt(hungerField.getText()),
                                Integer.parseInt(maxHungerField.getText()),
                                godModeCheckBox.isSelected()
                        );
                    } catch (NumberFormatException ex) {
                        showError("Please enter valid numbers for all numeric fields.");
                    }
                }
            }
        });

        JButton updateButton = new JButton("Update");
        updateButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                int selectedIndex = steveList.getSelectedIndex();
                if (selectedIndex >= 0 && listener != null) {
                    try {
                        listener.onUpdateSteve(
                                selectedIndex,
                                nameField.getText(),
                                Integer.parseInt(healthField.getText()),
                                Integer.parseInt(maxHealthField.getText()),
                                Integer.parseInt(attackPowerField.getText()),
                                Integer.parseInt(defensePowerField.getText()),
                                Integer.parseInt(hungerField.getText()),
                                Integer.parseInt(maxHungerField.getText()),
                                godModeCheckBox.isSelected()
                        );
                    } catch (NumberFormatException ex) {
                        showError("Please enter valid numbers for all numeric fields.");
                    }
                } else {
                    showError("Please select a Steve to update.");
                }
            }
        });

        JButton deleteButton = new JButton("Delete");
        deleteButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                int selectedIndex = steveList.getSelectedIndex();
                if (selectedIndex >= 0 && listener != null) {
                    int confirm = JOptionPane.showConfirmDialog(
                            SwingSteveView.this,
                            "Are you sure you want to delete this Steve?",
                            "Confirm Delete",
                            JOptionPane.YES_NO_OPTION
                    );
                    if (confirm == JOptionPane.YES_OPTION) {
                        listener.onDeleteSteve(selectedIndex);
                    }
                } else {
                    showError("Please select a Steve to delete.");
                }
            }
        });

        JButton clearButton = new JButton("Clear");
        clearButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (listener != null) {
                    listener.onClearForm();
                }
            }
        });

        buttonPanel.add(addButton);
        buttonPanel.add(updateButton);
        buttonPanel.add(deleteButton);
        buttonPanel.add(clearButton);

        add(buttonPanel, BorderLayout.SOUTH);
    }

    @Override
    public void showAllSteves(List<Steve> steves) {
        listModel.clear();
        for (Steve steve : steves) {
            listModel.addElement(steve);
        }
    }

    @Override
    public void showError(String message) {
        JOptionPane.showMessageDialog(this, message, "Error", JOptionPane.ERROR_MESSAGE);
    }

    @Override
    public void showSuccess(String message) {
        JOptionPane.showMessageDialog(this, message, "Success", JOptionPane.INFORMATION_MESSAGE);
    }

    @Override
    public void clearForm() {
        nameField.setText("");
        healthField.setText("");
        maxHealthField.setText("");
        attackPowerField.setText("");
        defensePowerField.setText("");
        hungerField.setText("");
        maxHungerField.setText("");
        godModeCheckBox.setSelected(false);
    }

    @Override
    public void setFormFields(Steve steve) {
        nameField.setText(steve.getName());
        healthField.setText(String.valueOf(steve.getHealth()));
        maxHealthField.setText(String.valueOf(steve.getMaxHealth()));
        attackPowerField.setText(String.valueOf(steve.getAttackPower()));
        defensePowerField.setText(String.valueOf(steve.getDefensePower()));
        hungerField.setText(String.valueOf(steve.getHunger()));
        maxHungerField.setText(String.valueOf(steve.getMaxHunger()));
        godModeCheckBox.setSelected(steve.isGodMode());
    }

    @Override
    public void setSteveListener(SteveListener listener) {
        this.listener = listener;
    }
}

